==> dde-network-core_1.0.47.orig.tar.xz: dde-network-core-1.0.47/dss-network-plugin/translations/dss-network-plugin_ms.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ms" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 mesej baharu</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 bersambung</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Sambungan Berwayar</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Kawasan Khas</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Jenis Keselamatan</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Jalur</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Saluran</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Antara Muka</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Topeng Rangkaian</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Get Laluan</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Utama</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Awalan</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Kelajuan</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Peranti dilumpuhkan</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Bersambung tetapi tiada capaian Internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Tidak bersambung</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Kabel rangkaian telah dicabut</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Menyambung</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Mengesahihkan</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Mendapatkan alamat IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Bersambung</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Terputus</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP berkonflik</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Gagal</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Rangkaian Berwayar</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rangkaian Berwayar %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rangkaian Tanpa Wayar</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Sambungan Tanpa Wayar %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Peranti dilumpuhkan</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Kabel rangkaian telah dicabut</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Tidak bersambung</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Menyambung</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Bersambung tetapi tiada capaian Internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Sambungan gagal</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP berkonflik</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Lumpuhkan sambungan berwayar</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Benarkan sambungan berwayar</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Lumpuhkan sambungan tanpa wayar</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Benarkan sambungan tanpa wayar</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Lumpuhkan rangkaian</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Benarkan rangkaian</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Tetapan rangkaian</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.4.orig.tar.xz: dde-network-core-1.1.4/dss-network-plugin/translations/dss-network-plugin_ms.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ms">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 mesej baharu</translation>
    </message>
</context>
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Rangkaian Tanpa Wayar</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rangkaian Berwayar</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 bersambung</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Sambung ke rangkaian tersembunyi</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Kata Laluan</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Sambung</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Kawasan Khas</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Jenis Keselamatan</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Saluran</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Jalur</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Antara Muka</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Topeng Rangkaian</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Get Laluan</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Utama</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Awalan</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Kelajuan</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Peranti dilumpuhkan</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Bersambung tetapi tiada capaian Internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Tidak bersambung</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Kabel rangkaian telah dicabut</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Menyambung</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Mengesahihkan</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Mendapatkan alamat IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Bersambung</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Terputus</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP berkonflik</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Gagal</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Rangkaian Berwayar</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rangkaian Berwayar %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rangkaian Tanpa Wayar</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Sambungan Tanpa Wayar %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Peranti dilumpuhkan</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Kabel rangkaian telah dicabut</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Tidak bersambung</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Menyambung</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Bersambung tetapi tiada capaian Internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Sambungan gagal</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP berkonflik</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Lumpuhkan sambungan berwayar</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Benarkan sambungan berwayar</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Lumpuhkan sambungan tanpa wayar</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Benarkan sambungan tanpa wayar</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Lumpuhkan rangkaian</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Benarkan rangkaian</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Tetapan rangkaian</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Sambungan Berwayar</translation>
    </message>
</context>
</TS>
